# Intra Cluster Filtering

## Installation Instructions

It is necessary to use Python **Versión 3.10.14** for the installation and proper functioning of the library.

### Step 1: Create a New Environment

First, create a new environment with Python version 3.10.14.

### Step 2: Install Git

It is necessary to have Git installed for this installation. If you don't have Git installed, you can download it from [here](https://git-scm.com/downloads).

### Step 3: Install the Package

In your console (e.g., Anaconda Prompt), execute the following commands:
```sh
# Activate your environment
conda activate YourRepository

# Install the package from GitHub
pip install git+https://github.com/juanzamorai/intracluster-filtering.git
```

Once the installation is complete, you can start using the library. We recommend checking out the examples in the [`examples`](https://github.com/juanzamorai/intracluster-filtering/tree/main/examples) folder.


